@@ -1,5 +1,3 @@
-'use strict';
-
 const families = [
   {
     type: 'Mono',
@@ -34,11 +32,23 @@ const families = [
     hasItalic: false,
     unicodes: [],
   },
+  {
+    type: 'Sans Thai Looped',
+    name: 'IBM Plex Sans Thai Looped',
+    hasItalic: false,
+    unicodes: [],
+  },
   {
     type: 'Serif',
     name: 'IBM Plex Serif',
     unicodes: ['Latin1', 'Latin2', 'Latin3', 'Pi', 'Cyrillic'],
   },
+  {
+    type: 'Arabic',
+    name: 'IBM Plex Arabic',
+    hasItalic: false,
+    unicodes: [],
+  },
 ];
 
 module.exports = families;
